import datetime

from .base_config import Config


class DevelopmentConfig(Config):
    DEBUG = True
    JWT_ACCESS_TOKEN_EXPIRES = datetime.timedelta(days=15)
    SQLALCHEMY_DATABASE_URI = "mysql://groundworx:groundworx@mysql/groundworx"




import datetime
import os

basedir = os.path.abspath(os.path.dirname(__file__))


class Config(object):
    # JWT CONF
    JWT_SECRET_KEY = os.environ.get('JWT_SECRET')
    JWT_ALGORITHM = os.environ.get('JWT_SECRET', "RS256")
    JWT_ACCESS_TOKEN_EXPIRES = datetime.timedelta(days=1)

    # DATABASE
    SQLALCHEMY_DATABASE_URI = os.environ.get(
        'DATABASE_URL') or 'sqlite:///' + os.path.join(basedir, 'app.db')
    SQLALCHEMY_TRACK_MODIFICATIONS = False

    @staticmethod
    def init_app(app):
        pass


import datetime

from .base_config import Config


class ProductionConfig(Config):
    JWT_ACCESS_TOKEN_EXPIRES = datetime.timedelta(days=7)
    SQLALCHEMY_DATABASE_URI = "mysql://groundworx:groundworx@mysql/groundworx"


import sqlalchemy
from sqlalchemy.exc import IntegrityError

from gwlib.base.base_service import BaseService
from gwlib.http.responses import HTTP_BAD_REQUEST, HTTP_CONFLICT


class BaseController:

    def build_response(self, method=None, **kwargs):
        """
        Method to call a Service function and return a Http Response
        :type kwargs: dict
        :type method: function
        """
        try:
            response = method(**kwargs)
        except KeyError as e:
            return HTTP_BAD_REQUEST(e)
        except IntegrityError as e:
            return HTTP_CONFLICT(e)
        except sqlalchemy.exc.InvalidRequestError as e:
            return HTTP_CONFLICT(e)
        return response




controller = BaseController()
user_service = BaseService()


# mi ruta
def save_user(**kwargs):
    return controller.build_response(method=user_service.save, **kwargs)




import hashlib

from gwlib.base.base_dao import BaseDAO
from gwlib.base.errors import FieldRequired


class BaseService:
    def __init__(self, session=None, model=None):
        self.data = {}
        self.dao = BaseDAO(session=session, model=model)

    def validate(self):
        pass

    def __save(self):
        self.validate()
        self.before_save()
        self.dao.save(**self.data)
        self.after_save()

    def before_save(self):
        pass

    def after_save(self):
        pass

    def save(self, data=None):
        self.data = data
        self.__save()


class UserService(BaseService):
    required_fields = ["username"]

    def __init__(self, session=None, model=None):
        super(UserService).__init__(session=session, model=model)

    def validate(self):
        for key in self.required_fields:
            if key not in self.data:
                raise FieldRequired

cdb_prod = Server("https://admin:linkaform2018server.@couchdb.linkaform.com")
username = "username"
user_id = 000
cdb_prod.remove_user(username)
account = "account_0000"
cdb_prod.add_user(username, password, [account])









class BaseDAO:
    def __init__(self, session, model, data):
        self.model = model
        self.session = session

    def save(self, **kwargs):
        self.model(data)
        self.session.add(self.model)
        self.session.commit()

    def update(self):
        self.model(**self.data)
        self.session.add(self.model)
        self.session.commit()

    def delete(self):
        self.model(**self.data)
        self.session.add(self.model)
        self.session.commit()

    def get(self):
        self.model(**self.data)
        self.session.add(self.model)
        self.session.commit()


import setuptools
import os
version = os.environ.get('VERSION', 3)
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='gw-md-lib',
    version='0.{}'.format(version),
    author="Auriz",
    author_email="edominguez@auriz.biz",
    description="Common lib to GW project",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    python_requires='>=3.6',
    classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )
